@@ -1,15 +1,20 @@
-import random
-import string
-import re
-import urlparse
 import os
+import random
+import re
+import string
+
+try:
+    from urllib.parse import urlparse
+except ImportError:
+    from urlparse import urlparse
+
 
 DEFAULT_PREFIX = 'kr/'
 
 
 def gen_hash(len=5):
     """Create a random alphanumeric hash of a given length"""
-    return ''.join([random.choice(string.ascii_lowercase + string.digits) for _ in xrange(len)])
+    return ''.join([random.choice(string.ascii_lowercase + string.digits) for _ in range(len)])
 
 
 def slugify(title):
@@ -34,7 +39,7 @@ def is_url(str):
 
 def url_filename(url):
     """Extract the filename from URL (if present)"""
-    path = urlparse.urlparse(url).path
+    path = urlparse(url).path
     fname = os.path.basename(path)
     if not fname:
         fname = "notebook-" + gen_hash()
